
library(ggplot2)
library(grid)
library(rworldmap)
library(easyNCDF)

ref.file <- '/esarchive/recon/ecmwf/era5/daily_mean/tas_f1h/tas_201001.nc'
outfile <- 'era5-decathlon-peninsula.nc'

lat <- NcToArray(ref.file, vars_to_read='latitude')
lon <- NcToArray(ref.file, vars_to_read='longitude')
lat <- lat[1,]
lon <- lon[1,]
lon <- ((lon + 180) %% 360) - 180

# Get the world map
worldMap <- getMap()
# Member States of the European Union
europeanUnion <- c("Spain")
# Select only the index of states member of the E.U.
indEU <- which(worldMap$NAME%in%europeanUnion)

# Extract longitude and latitude border's coordinates of members states of E.U. 
europeCoords <- lapply(indEU, function(i){
  df <- data.frame(worldMap@polygons[[i]]@Polygons[[1]]@coords)
  df$region =as.character(worldMap$NAME[i])
  colnames(df) <- list("long", "lat", "region")
  return(df)
})

europeCoords <- do.call("rbind", europeCoords)

in.country <- function(lon,lat){
    point.in.polygon(lon,lat,europeCoords$long,europeCoords$lat)
}

mask <- outer(lon,lat,in.country)
names(dim(mask)) <- c('longitude', 'latitude')

get_latlon <- function(lat, lon){

    longitude <- lon
    dim(longitude) <- length(longitude)
    metadata <- list(longitude = list(units = 'degrees_east'))
    attr(longitude, 'variables') <- metadata
    names(dim(longitude)) <- 'longitude'
    
    latitude <- lat
    dim(latitude) <- length(latitude)
    metadata <- list(latitude = list(units = 'degrees_north'))
    attr(latitude, 'variables') <- metadata
    names(dim(latitude)) <- 'latitude'

    return(list(lat=latitude,lon=longitude))
}

grid <- get_latlon(lat,lon)
ArrayToNc(list(mask, grid$lat, grid$lon),outfile) 

